#ifndef _UNPICKLER_H
#define _UNPICKLER_H

/**
    Kaya run-time system
    Copyright (C) 2004, 2005 Edwin Brady

    This file is distributed under the terms of the GNU Lesser General
    Public Licence. See COPYING for licence.
*/
#include "wchar.h"
#include "Heap.h"

Value* unmarshal(void* vmptr, wchar_t* x, kint id);

Value* unpickle(VMState* vm, vector<Value*>&,wchar_t* &x,kint id);
kint read_int(VMState* vm, wchar_t* &x);
Value* un_int(VMState* vm, vector<Value*>&,wchar_t* &x);
Value* un_real(VMState* vm, vector<Value*>&,wchar_t* &x);
Value* un_circle(VMState* vm, vector<Value*>&,wchar_t* &x);
Value* un_string(VMState* vm, vector<Value*>&,wchar_t* &x);
Value* un_array(VMState* vm, vector<Value*>&,wchar_t* &x,kint id);
Value* un_union(VMState* vm, vector<Value*>&,wchar_t* &x,kint id);
Value* un_closure(VMState* vm, vector<Value*>&,wchar_t* &x,kint id);

#endif
